// based on the sourcefile for lesson 16 in Lazyfoo's SDL tutorial
//The headers
#include <SDL/SDL.h>
#include <SDL/SDL_image.h>
#include <string>
#include <vector>
#include <iostream>
#include <fstream>
#include <cmath>

using namespace std;
#define PI (3.1415926)
#define modifier float(0.5)
//The screen attributes
const int SCREEN_WIDTH = 640;
const int SCREEN_HEIGHT = 480;
const int SCREEN_BPP = 32;
// since our ship is round, the radius would be helpful for collision detection
const int radius = 15;

//The frame rate
const int FRAMES_PER_SECOND = 20;

//The dimensions of the dot
const int DOT_WIDTH = 36;
const int DOT_HEIGHT = 36;

//The surfaces
SDL_Surface *spritesheet = NULL;
SDL_Surface *thrustsheet = NULL;
SDL_Surface *screen = NULL;
SDL_Surface *blank = NULL;


//The event structure
SDL_Event event;

SDL_Rect clip[360];// a different ship sprite for ever degree the ship turns
int counter = 0; // for counting the position in the clip array
int cx = 0;
int cy = 0;
bool quit = false;

int coordinate[4];
int ccounter = 0;

void setpixel(SDL_Surface *screen, int x, int y, Uint8 r, Uint8 g, Uint8 b)
{
	Uint8 *ubuff8;
	Uint16 *ubuff16; 
	Uint32 *ubuff32;
	Uint32 color;

    if (x > screen->w || y > screen->h || x < 0 || y < 0)
        return;
	
	/* Lock the screen, if needed */
	if(SDL_MUSTLOCK(screen)) {
		if(SDL_LockSurface(screen) < 0) 
			return;
	}
 
	/* Get the color */
	color = SDL_MapRGB( screen->format, r, g, b );
	
	/* How we draw the pixel depends on the bitdepth */
	switch(screen->format->BytesPerPixel) {
		case 1: 
			ubuff8 = (Uint8*) screen->pixels;
			ubuff8 += (y * screen->pitch) + x; 
			*ubuff8 = (Uint8) color;
			break;
		case 2:
			ubuff16 = (Uint16*) screen->pixels;
			ubuff16 += ((y * screen->pitch)>>2) + x;
			*ubuff16 = (Uint16) color; 
			break;  
		case 3:
			ubuff8 = (Uint8*) screen->pixels;
			ubuff8 += (y * screen->pitch) + x;
					
			r = (color>>screen->format->Rshift)&0xFF;
			g = (color>>screen->format->Gshift)&0xFF;
			b = (color>>screen->format->Bshift)&0xFF;

			ubuff8[0] = r;
			ubuff8[1] = g;
			ubuff8[2] = b;
			break;
				
		case 4:
			ubuff32 = (Uint32*) screen->pixels;
			ubuff32 += ((y*screen->pitch)>>2) + x;
			*ubuff32 = color;
			break;
	
		default:
			fprintf(stderr, "Error: Unknown bitdepth!\n");
	}

	/* Unlock the screen if needed */
	if(SDL_MUSTLOCK(screen)) {
		SDL_UnlockSurface(screen);
	}
}

class coordinates
{
	public:
		int x;
		int y;
};

class lines
{
	public:
		int x;
		int y;
		int x1;
		int y1;
		int b;
		float slope;
		int landable;
		std::vector<coordinates> listofpoints;
};
void Line(SDL_Surface *screen, float x1, float y1, float x2, float y2, Uint8 r, Uint8 g, Uint8 b)
{
    // Bresenham's line algorithm
    const bool steep = (fabs(y2 - y1) > fabs(x2 - x1));
    if(steep)
    {
        std::swap(x1, y1);
        std::swap(x2, y2);
    }

    if(x1 > x2)
    {
        std::swap(x1, x2);
        std::swap(y1, y2);
    }

    const float dx = x2 - x1;
    const float dy = fabs(y2 - y1);

    float error = dx / 2.0f;
    const int ystep = (y1 < y2) ? 1 : -1;
    int y = (int)y1;

    const int maxX = (int)x2;

    for(int x=(int)x1; x<maxX; x++)
    {
        if(steep)
        {
            setpixel(screen,y,x,r,g,b);
        }
        else
        {
            setpixel(screen,x,y,r,g,b);
        }

        error -= dy;
        if(error < 0)
        {
            y += ystep;
            error += dx;
        }
    }
}

//The dot that will move around on the screen
class Dot
{
    private:
    //The X and Y offsets of the dot
    int x, y;
	int oldx,oldy;
	//determines when the ship has thrust on
	int thrustswitch;
	
	

    public:
	//did the ship land?
	int landed;
    //Initializes the variables
	//The velocity of the dot
	float xVel;
	float yVel;
	//The acceleration of the dot
	float xaccel;
	float yaccel;
	
	//angle of the ship
	int angle;
    Dot();
	std::vector<lines> linelist;
    //Takes key presses and adjusts the dot's velocity
    void handle_input(Uint8 *keystates);
	void handle_input_press();
    //Moves the dot
    void move();
	//main function must have access to these variables so the user input value can be inputted
	float thrust;
	float gravity;
	int fuel;
	int usefuel;
    //Shows the dot on the screen
    void show();
};

//The timer
class Timer
{
    private:
    //The clock time when the timer started
    int startTicks;

    //The ticks stored when the timer was paused
    int pausedTicks;

    //The timer status
    bool paused;
    bool started;

    public:
    //Initializes variables
    Timer();

    //The various clock actions
    void start();
    void stop();
    void pause();
    void unpause();

    //Gets the timer's time
    int get_ticks();

    //Checks the status of the timer
    bool is_started();
    bool is_paused();
};
//used to store lines given in the text file

SDL_Surface *load_image( std::string filename )
{
    //The image that's loaded
    SDL_Surface* loadedImage = NULL;

    //The optimized surface that will be used
    SDL_Surface* optimizedImage = NULL;

    //Load the image
    loadedImage = IMG_Load( filename.c_str() );

    //If the image loaded
    if( loadedImage != NULL )
    {
        //Create an optimized surface
        optimizedImage = SDL_DisplayFormat( loadedImage );

        //Free the old surface
        SDL_FreeSurface( loadedImage );

        //If the surface was optimized
        if( optimizedImage != NULL )
        {
            //Color key surface
            SDL_SetColorKey( optimizedImage, SDL_SRCCOLORKEY, SDL_MapRGB( optimizedImage->format, 0xFF, 0xFF, 0xFF ) );
        }
    }

    //Return the optimized surface
    return optimizedImage;
}

void apply_surface( int x, int y, SDL_Surface* source, SDL_Surface* destination, SDL_Rect* clip = NULL )
{
    //Holds offsets
    SDL_Rect offset;

    //Get offsets
    offset.x = x;
    offset.y = y;

    //Blit
    SDL_BlitSurface( source, clip, destination, &offset );
}

bool init()
{
    //Initialize all SDL subsystems
    if( SDL_Init( SDL_INIT_EVERYTHING ) == -1 )
    {
        return false;
    }

    //Set up the screen
    screen = SDL_SetVideoMode( SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP, SDL_SWSURFACE );

    //If there was an error in setting up the screen
    if( screen == NULL )
    {
        return false;
    }

    //Set the window caption
    SDL_WM_SetCaption( "Lunar Lander", NULL );

    //If everything initialized fine
    return true;
}

bool load_files()
{
    //Load the dot image
        //dot = load_image( "dot.bmp" );
	spritesheet = load_image("sheet.bmp");
	thrustsheet = load_image("thrust.bmp");
	blank = load_image("blank.bmp");
    //If there was a problem in loading the dot
	if(spritesheet == NULL||blank == NULL||thrustsheet== NULL )
    {
        return false;
    }

    //If everything loaded fine
    return true;
}

void clean_up()
{
    //Free the surface
    //SDL_FreeSurface( dot );
	SDL_FreeSurface(spritesheet);
	SDL_FreeSurface(blank);
	spritesheet = NULL;
	blank = NULL;
    //Quit SDL
    SDL_Quit();
}

Dot::Dot()
{
    //Initialize the offsets
    x = SCREEN_WIDTH/2;
    y = 0;
	angle = 0;
	oldx = SCREEN_WIDTH/2;
	oldy = 0;
	landed = 0;
	lines initline;
	coordinates u;
	thrustswitch = 0;
	u.x = 0;
	u.y=0;
	fuel = 750;
	xaccel = 0;
	yaccel = 0;
	initline.b=0;
	initline.landable=0;
	initline.listofpoints.push_back(u);
	initline.slope=0;
	initline.x=0;
	initline.y=0;
	initline.x1=0;
	initline.y1=0;
	linelist.push_back(initline);

	    //Initialize the velocity
    xVel = 0;
	yVel = 0;
}

void Dot::handle_input(Uint8 *keystates)
{
    //If a key was pressed
	if( keystates[SDLK_SPACE])
	{
		if(landed!=1&&fuel>=1)
		{
			thrustswitch = 1;
			xaccel = thrust * cosf((float(PI*(angle+90)/180)));
			yaccel = thrust * sinf((float(PI*(angle+90)/180)));
			fuel-=1;
		}
	}
	if( keystates[SDLK_RIGHT])
	{
		if(landed!=1)
		{
			angle+=4;
			if(angle > 359)
			{
				angle = 0;
			}
		}
		//system ( "cls" ); 
		//printf("%d",angle);
	}
	if( keystates[SDLK_LEFT])
	{
		if(landed!=1)
		{
			angle-=4;
			if(angle<0)
			{
				angle = 359;
			}
		}
		//system ( "cls" ); 
		//printf("%d",angle);
	}
	if(keystates[SDLK_q])
	{
		quit = true;
	}
    //If a key was released
    /*else if( event.type == SDL_KEYUP )
    {
        //Adjust the velocity
        switch( event.key.keysym.sym )
        {
            case SDLK_UP: yVel += DOT_HEIGHT / 2; break;
            case SDLK_DOWN: yVel -= DOT_HEIGHT / 2; break;
            case SDLK_LEFT: xVel += DOT_WIDTH / 2; break;
            case SDLK_RIGHT: xVel -= DOT_WIDTH / 2; break;
        }
    }*/
}

void Dot::handle_input_press()
{
	if( event.type == SDL_KEYDOWN )
	{
	    // calculate the acceleration and Adjust the velocity
	    switch( event.key.keysym.sym )
	    {
			case SDLK_SPACE:
			{
				if(fuel>=1&&landed!=1)
				{
					thrustswitch = 1;
					xaccel = thrust * cosf((float(PI*(angle+90)/180)));
					yaccel = thrust * sinf((float(PI*(angle+90)/180)));
					fuel-=1;
				}
				break;
			}
			case SDLK_RIGHT:
			{
				if(landed!=1)
				{
					angle+=4;
					if(angle > 359)
					{
						angle = 0;
					}
				}
				//system ( "cls" ); 
				//printf("%d\n",angle);
				break;
			}
			case SDLK_LEFT:
			{
				if(landed!=1)
				{
					angle-=4;
					if(angle > 359)
					{
						angle = 0;
					}
				}
				//system ( "cls" ); 
				//printf("%d\n",angle);
				break;
			}
			case SDLK_q:
			{
				quit = true;
				break;
			}
	    }
	}
}

void Dot::move()
{
	if(landed == 0)
	{
		xVel+=xaccel*modifier*modifier;
		yVel+=yaccel*modifier*modifier;
		yVel+=gravity*modifier*modifier;
		//yaccel=-gravity;
		//Move the dot left or right
		oldx = x;
		oldy = y;
		x += int(xVel*modifier);
		yaccel = 0;
		xaccel = 0;
		//If the dot went too far to the left or right
		if( ( x+6 < 0 ) || ( x + DOT_WIDTH -6 > SCREEN_WIDTH ) )
		{
			if(x+6 < 0)
			{
				x = 0-6;
			}
			else if(x + DOT_WIDTH - 6 > SCREEN_WIDTH)
			{
				x = SCREEN_WIDTH - DOT_WIDTH+6;
				
			}
			xaccel = 0;
			yaccel = 0;
			xVel = 0;
			yVel = 0;

		    //move back
		    //x -= xVel;
		}
		
		//Move the dot up or down
		y += int(yVel*modifier);
		
		//If the dot went too far up or down
		if( ( y+6 < 0 ) || ( y + DOT_HEIGHT - 6 > SCREEN_HEIGHT ) )
		{
			if(y+6 < 0)
			{
				y = 0-6;
			}
			else if(y + DOT_HEIGHT -6  > SCREEN_HEIGHT)
			{
				y = SCREEN_HEIGHT - DOT_HEIGHT + 6;
			}
			//check if ship collided with a line
		    //move back
		    //y -= yVel;
			xaccel = 0;
			yaccel = 0;
			xVel = 0;
			yVel = 0;
		}
		for(int i = 1; i < linelist.size();i++)
		{
			//system("clear");
			//printf("checking\n");
			for(int j=1;j<linelist.at(i).listofpoints.size();j++)
			{
				int distance = 0;
				//check if ship is left of the dot or the right, ship will always be ontop of the line
				if(x+6<linelist.at(i).listofpoints.at(j).x)
				{
					distance = int(sqrt(double(pow(abs(y + DOT_HEIGHT - 6 - radius -linelist.at(i).listofpoints.at(j).y),2)+pow(abs(x+6+radius-linelist.at(i).listofpoints.at(j).x),2))));
				}
				else if(x + DOT_WIDTH - 6>linelist.at(i).listofpoints.at(j).x) 
				{
					distance = int(sqrt(double(pow(abs(y + DOT_HEIGHT - 6 - radius -linelist.at(i).listofpoints.at(j).y),2)+pow(abs(x + DOT_WIDTH - 6 - radius + DOT_WIDTH - 6-linelist.at(i).listofpoints.at(j).x),2))));
				}
				else if (x +  DOT_WIDTH - 6 - radius == linelist.at(i).listofpoints.at(j).x)
				{
					distance = int(sqrt(double(pow(abs(y + DOT_HEIGHT - 6 - radius -linelist.at(i).listofpoints.at(j).y),2)+pow(abs(x+6+radius-linelist.at(i).listofpoints.at(j).x),2))));
				}
				
				if( distance <= radius)
				{
					yaccel = 0;
					xaccel = 0;
					xVel = 0;
					yVel = 0;
					if(angle== 359)
					{
						angle = 0;
					}
					if (usefuel !=1)
					{	if(y >linelist.at(i).listofpoints.at(j).y)
						{
							y =  linelist.at(i).listofpoints.at(j).y-DOT_HEIGHT+6;
						}
						else if(y<linelist.at(i).listofpoints.at(j).y)
						{
							y = y;
						}
					}
					landed = 1;
					if(yVel >21 || angle != 0 || linelist.at(i).landable == 0)
					{
						system("clear");
						printf("you crashed!\n");
						printf("press q to quit\n");
					}
					else if (yVel <=20 && angle == 0 && linelist.at(i).landable == 1)
					{
						system("clear");
						printf("you landed!\n");
						printf("press q to quit\n");
					}
	
					//system("clear");
					//printf("colided with a line\n");
					//printf("edges of the line: %d, %d - %d, %d\n",linelist.at(i).x,linelist.at(i).y,linelist.at(i).x1,linelist.at(i).y1);
					//printf("collision point %d, %d\n",linelist.at(i).listofpoints.at(j).x,linelist.at(i).listofpoints.at(j).y);
					//printf("slope of the line:%f, y-intercept of the line:%d\n",linelist.at(i).slope,linelist.at(i).b);
					//setpixel(screen,linelist.at(i).listofpoints.at(j).x,linelist.at(i).listofpoints.at(j).y,255,0,0);
				}
			}
		}
	}
}

void Dot::show()
{
    //Show the dot and wipe the previous dot
	apply_surface( oldx, oldy, blank, screen);
	if(thrustswitch ==0)
	{
		
		apply_surface( x, y, spritesheet, screen,&clip[angle]);
	}
	else if(thrustswitch ==1)
	{
		apply_surface( x, y, thrustsheet, screen,&clip[angle]);
		thrustswitch = 0;
	}
}

Timer::Timer()
{
    //Initialize the variables
    startTicks = 0;
    pausedTicks = 0;
    paused = false;
    started = false;
}

void Timer::start()
{
    //Start the timer
    started = true;

    //Unpause the timer
    paused = false;

    //Get the current clock time
    startTicks = SDL_GetTicks();
}

void Timer::stop()
{
    //Stop the timer
    started = false;

    //Unpause the timer
    paused = false;
}

void Timer::pause()
{
    //If the timer is running and isn't already paused
    if( ( started == true ) && ( paused == false ) )
    {
        //Pause the timer
        paused = true;

        //Calculate the paused ticks
        pausedTicks = SDL_GetTicks() - startTicks;
    }
}

void Timer::unpause()
{
    //If the timer is paused
    if( paused == true )
    {
        //Unpause the timer
        paused = false;

        //Reset the starting ticks
        startTicks = SDL_GetTicks() - pausedTicks;

        //Reset the paused ticks
        pausedTicks = 0;
    }
}

int Timer::get_ticks()
{
    //If the timer is running
    if( started == true )
    {
        //If the timer is paused
        if( paused == true )
        {
            //Return the number of ticks when the timer was paused
            return pausedTicks;
        }
        else
        {
            //Return the current time minus the start time
            return SDL_GetTicks() - startTicks;
        }
    }

    //If the timer isn't running
    return 0;
}

bool Timer::is_started()
{
    return started;
}

bool Timer::is_paused()
{
    return paused;
}

int main( int argc, char* args[] )
{
    

    //The dot that will be used
    Dot myDot;
	myDot.gravity = NULL;
	myDot.thrust = NULL;
    //The frame rate regulator
    Timer fps;
	std::string filename;
    //Initialize
    if( init() == false )
    {
        return 1;
    }
	//parse the command line arguments
	for(int i = 1; i<argc; i++)
	{
		if(i<argc-1)
		{
			if(args[i+1][0] != '-'|| (args[i+1][0] == '-'&& isdigit(args[i+1][1])))
			{
				//printf("we're in here!\n");
				if(args[i][0] == '-' && args[i][1] == 'f' && strlen(args[i])==2)
				{
					//printf("we at f flag\n");
					filename+= args[i+1];
				}
				else if(args[i][0] == '-' && args[i][1] == 't' && strlen(args[i])==2)
				{
					//printf("we're here!\n");
					//printf("we at t flag,%f\n",-1*float(atof(args[i+1])));
					for(int u = 0; u < strlen(args[i+1]); u++)// check if data for -t tag contain any character that is not a number, for example -t 15s
					{
						if(!isdigit(args[i+1][u])&& args[i+1][u]!= '-'&&args[i+1][u]!= '.')
						{
							printf("data provided for -t argument is not a number\n");
							exit(8);
						}
					}
					myDot.thrust += 1*float(atof(args[i+1]));
					//printf("thrust:%f\n",myDot.thrust);
				}
				else if(args[i][0] == '-' && args[i][1] == 'u' && strlen(args[i])==2)
				{
					//printf("we're here!\n");
					//printf("we at t flag,%f\n",-1*float(atof(args[i+1])));
					for(int u = 0; u < strlen(args[i+1]); u++)// check if data for -t tag contain any ch
					{
						if(!isdigit(args[i+1][u])&& args[i+1][u]!= '-'&&args[i+1][u]!= '.')
						{
							printf("data provided for -u argument is not a number\n");
							exit(8);
						}
					}
					myDot.usefuel=1;
					myDot.fuel = atoi(args[i+1]);
					//printf("thrust:%f\n",myDot.thrust);
				}
				else if(args[i][0] == '-' && args[i][1] == 'g' && strlen(args[i])==2)
				{
					//printf("we at g flag\n");
					for(int u = 0; u < strlen(args[i+1]); u++)// check if data for -g tag contain any character that is not a number, for example -g 15s
					{
						if(!isdigit(args[i+1][u])&& args[i+1][u]!= '-'&&args[i+1][u]!= '.')
						{
							printf("data provided for -g argument is not a number\n");
							exit(8);
						}
					}
					myDot.gravity = float(atof(args[i+1]));
				}
				else
				{
					//printf("%s\n",args[i]);
					printf("not a legit flag,please use either -g/-t/-f \n");
				}
			}
		}
	}
	//myDot.thrust*=-1;
    //Load the files
    if( load_files() == false )
    {
        return 1;
    }
	ifstream filter(filename.data());
	filename.insert(filename.size()-4,"_actual");
	remove(filename.data());
	ofstream write(filename.data());
	char c;
	int writenewline = 0;
	int writespace = 0;
	if(filter.is_open())
	{
		while(!filter.eof())
		{
			c = filter.get();
			printf("%c\n",c);
			if(int(c)>=0 && int(c)<=127)
			{
				if(isdigit(c))
				{
					printf("write\n");
					writenewline = 1;
					writespace = 1;
					if(write.is_open())
					{
						write.put(c);
					}
				}
				else if(!isdigit(c))
				{
					if(c == ' ')
					{
						if(writespace ==1)
						{
							printf("write\n");
							if(write.is_open())
							{
								write.put(c);
							}
							writespace = 0;
						}
						else
						{
							printf("no write\n");
						}
					}
					else if(c == char(10))
					{
						if(writenewline ==1)
						{
							printf("write\n");
							if(write.is_open())
							{
								write.put(c);
							}
							writenewline = 0;
							writespace = 0;
						}
						else
						{
							printf("contain empty line,rejecting file\n");
							exit(8);
						}
					}
				}
			}
		}
		filter.close();
		write.close();
	}
	else
	{
		printf("file not found\n");
		exit(8);
	}
	//load the landscape files
	ifstream input(filename.data());
	std::string number;
	std::string x = "";
	std::string y = "";
	std::string x1 = "";
	std::string y1 = "";
	lines data;
	int initial = 1;
	if(input.is_open())
	{
		while(!input.eof())
		{
			if(initial == 1)
			{
				initial = 0;
				getline(input,number,char(10));
				x = number.substr(0,number.find(' ')+1);
				y = number.substr(number.find(' ')+1,number.length() - number.find(' ')+1);
				getline(input,number,char(10));
				x1 = number.substr(0,number.find(' ')+1);
				y1 = number.substr(number.find(' ')+1,number.length() - number.find(' ')+1);
				data.x=atoi(x.data());
				data.y=atoi(y.data());
				data.x1=atoi(x1.data());
				data.y1=atoi(y1.data());
				myDot.linelist.push_back(data);
			}
			else if( initial == 0)
			{
				x = x1;
				y = y1;
				getline(input,number,char(10));
				if(number=="")
				{
					break;
				}
				x1 = number.substr(0,number.find(' ')+1);
				y1 = number.substr(number.find(' ')+1,number.length() - number.find(' ')+1);
				data.x=atoi(x.data());
				data.y=atoi(y.data());
				data.x1=atoi(x1.data());
				data.y1=atoi(y1.data());
				myDot.linelist.push_back(data);
			}
			//printf("%s,%d\n",number.data(),number.length());
		}
		input.close();
	}
	for(int i = 1; i < myDot.linelist.size(); i ++)
	{
		printf("%d\n",i);
		// calculate if line segement is "landable"
		if(myDot.linelist.at(i).y == myDot.linelist.at(i).y1)
		{
			myDot.linelist.at(i).landable = 1;
		}
		else
		{
			myDot.linelist.at(i).landable = 0;
		}
		printf("landable calculated\n");
		coordinates point;
		// calculate slope and y intersection, what points with integer coordinates are within each line
		if(myDot.linelist.at(i).x > myDot.linelist.at(i).x1)
		{
			printf("compared\n");
			myDot.linelist.at(i).slope = (float(myDot.linelist.at(i).y)-float(myDot.linelist.at(i).y1))/(float(myDot.linelist.at(i).x)-float(myDot.linelist.at(i).x1));
			myDot.linelist.at(i).b = int(myDot.linelist.at(i).y - myDot.linelist.at(i).slope * myDot.linelist.at(i).x);
			printf("intersect calculated\n");
			for(int j = myDot.linelist.at(i).x1; j <= myDot.linelist.at(i).x; j++)
			{
				point.x = j;
				point.y = int(j*myDot.linelist.at(i).slope + myDot.linelist.at(i).b);
				myDot.linelist.at(i).listofpoints.push_back(point);
			}
		}
		else if (myDot.linelist.at(i).x < myDot.linelist.at(i).x1)
		{
			printf("compared\n");
			myDot.linelist.at(i).slope = (float(myDot.linelist.at(i).y1)-float(myDot.linelist.at(i).y))/(float(myDot.linelist.at(i).x1)-float(myDot.linelist.at(i).x));
			myDot.linelist.at(i).b = int(myDot.linelist.at(i).y - myDot.linelist.at(i).slope * myDot.linelist.at(i).x);
			printf("intersect calculated\n");
			for(int j = myDot.linelist.at(i).x; j <= myDot.linelist.at(i).x1; j++)
			{
				point.x = j;
				point.y = int(j*myDot.linelist.at(i).slope + myDot.linelist.at(i).b);
				myDot.linelist.at(i).listofpoints.push_back(point);
			}
		}
		else if (myDot.linelist.at(i).x == myDot.linelist.at(i).x1)
		{
			if (myDot.linelist.at(i).y< myDot.linelist.at(i).y1)
			{
				for( int j = myDot.linelist.at(i).y; j <= myDot.linelist.at(i).y1; j++)
				{
					point.x = myDot.linelist.at(i).x;
					point.y = j;
					myDot.linelist.at(i).listofpoints.push_back(point);	
				}
			}
			else if(myDot.linelist.at(i).y> myDot.linelist.at(i).y1)
			{
				for( int j = myDot.linelist.at(i).y1; j <= myDot.linelist.at(i).y; j++)
				{
					point.x = myDot.linelist.at(i).x;
					point.y = j;
					myDot.linelist.at(i).listofpoints.push_back(point);	
				}
			}
		}
	}
	// load the first 337 sprite into each clip slot
	for(int j = 0; j<=11;j++)
	{
		for(int i = 0; i<=27; i++)
		{
			clip[counter].x = i*36;
			clip[counter].y = j*36;
			clip[counter].w = 36;
			clip[counter].h = 36;
			counter++;
		}
	}
	//load the last 23 sprites
	for(int i = 0; i <=23; i++)
	{
		clip[counter].x = i*36;
		clip[counter].y = 12*36;
		clip[counter].w = 36;
		clip[counter].h = 36;
		counter++;
	}
	//printf("print something\n");
	//system ( "cls" ); 
	//Fill the screen white once
    SDL_FillRect( screen, &screen->clip_rect, SDL_MapRGB( screen->format, 0xFF, 0xFF, 0xFF ) );
	// draw da lines
	for (int i=1; i < myDot.linelist.size(); i++) 
	{
		//printf("%d\n",myDot.linelist.at(i).listofpoints.size());
		Line(screen,float(myDot.linelist.at(i).x),float(myDot.linelist.at(i).y),float(myDot.linelist.at(i).x1),float(myDot.linelist.at(i).y1),0,0,0);
	}
	system("clear");
	printf("left arrow key rotates counter-clockwise, right clockwise, space for thrust, q to quit.\n");
	printf("press anykey to begin/make sure game window is focused before key is pressed\n");
	while(true)//wait for user to start the game
	{
		if(SDL_PollEvent(&event))
		{
			if( event.type == SDL_KEYDOWN )
			{
				break;
			}
		}
	}
    //While the user hasn't quit
    while( quit == false )
    {
        //Start the frame timer
        fps.start();

        //While there's events to handle
        while( SDL_PollEvent( &event ) )
        {
            //Handle events for the dot
			myDot.handle_input_press();
            //If the user has Xed out the window
            if( event.type == SDL_QUIT )
            {
                //Quit the program
                quit = true;
            }
        }
		Uint8 *keystates = SDL_GetKeyState( NULL );
		myDot.handle_input(keystates);
		//Fill the screen white once
		SDL_FillRect( screen, &screen->clip_rect, SDL_MapRGB( screen->format, 0xFF, 0xFF, 0xFF ) );
		// draw da lines
		for (int i=1; i < myDot.linelist.size(); i++) 
		{
			Line(screen,float(myDot.linelist.at(i).x),float(myDot.linelist.at(i).y),float(myDot.linelist.at(i).x1),float(myDot.linelist.at(i).y1),0,0,0);
			/*for(int j =0; j<myDot.linelist.at(i).listofpoints.size();j++)
			{
				setpixel(screen,myDot.linelist.at(i).listofpoints.at(j).x,myDot.linelist.at(i).listofpoints.at(j).y,255,0,0);
			}*/
		}
        	//Move the dot
		myDot.move();
		if(myDot.usefuel ==1&&myDot.landed!=1)
		{
			system("clear");
			printf("Velocity:%f Angle:%d Fuel:%d \n",myDot.yVel,myDot.angle,myDot.fuel);
		}
		else if(myDot.landed!=1)
		{
			system("clear");
			printf("Velocity:%f Angle:%d \n",myDot.yVel,myDot.angle);
		}
        //Show the dot on the screen
        myDot.show();
        //Update the screen
        if( SDL_Flip( screen ) == -1 )
        {
            return 1;
        }

        //Cap the frame rate
        if( fps.get_ticks() < 1000 / FRAMES_PER_SECOND )
        {
            SDL_Delay( ( 1000 / FRAMES_PER_SECOND ) - fps.get_ticks() );
        }
    }

    //Clean up
    clean_up();

    return 0;
}
